@@ -50,12 +50,10 @@
 extern "C" {
 #endif
 
-double bisection(DATA* data, threadData_t *threadData, double*, double*, double*, double*, LIST*, LIST*);
-int checkZeroCrossings(DATA *data, LIST *list, LIST*);
+int maxBisectionIterations = 0;
+void bisection(DATA* data, threadData_t *threadData, double*, double*, double*, double*, LIST*, LIST*);
 void saveZeroCrossingsAfterEvent(DATA *data, threadData_t *threadData);
 
-int checkForStateEvent(DATA* data, LIST *eventList);
-
 /*! \fn checkForSampleEvent
  *
  *  \param [ref] [data]
@@ -101,8 +99,11 @@ int checkForStateEvent(DATA* data, LIST *eventList)
   for(i=0; i<data->modelData->nZeroCrossings; i++)
   {
     int *eq_indexes;
-    const char *exp_str = data->callback->zeroCrossingDescription(i,&eq_indexes);
-    debugStreamPrintWithEquationIndexes(LOG_EVENTS, 1, eq_indexes, "%s", exp_str);
+    if (DEBUG_STREAM(LOG_EVENTS))
+    {
+      const char *exp_str = data->callback->zeroCrossingDescription(i,&eq_indexes);
+      debugStreamPrintWithEquationIndexes(LOG_EVENTS, omc_dummyFileInfo, 1, eq_indexes, "%s", exp_str);
+    }
 
     if(sign(data->simulationInfo->zeroCrossings[i]) != sign(data->simulationInfo->zeroCrossingsPre[i]))
     {
@@ -139,21 +140,20 @@ int checkForStateEvent(DATA* data, LIST *eventList)
  *  then it de-activate the time events.
  *
  *  \param [ref] [data]
- *  \param [ref] [eventList]
- *  \param [in]  [eventTime]
- *  \param [ref] [solverInfo]
+ *  \param [ref] [threadData]
+ *  \param [ref] [eventLst]
+ *  \param [in]  [useRootFinding]
+ *  \param [out] [eventTime]
  *  \return 0: no event; 1: time event; 2: state event
  */
-int checkEvents(DATA* data, threadData_t *threadData, LIST* eventLst, double *eventTime, SOLVER_INFO* solverInfo)
+int checkEvents(DATA* data, threadData_t *threadData, LIST* eventLst, modelica_boolean useRootFinding, double *eventTime)
 {
   TRACE_PUSH
 
-  if (checkForStateEvent(data, solverInfo->eventLst))
+  int found = checkForStateEvent(data, eventLst);
+  if(found && useRootFinding)
   {
-    if (!solverInfo->solverRootFinding)
-    {
-      findRoot(data, threadData, solverInfo->eventLst, &(solverInfo->currentTime));
-    }
+    *eventTime = findRoot(data, threadData, eventLst, data->simulationInfo->timeValueOld, data->simulationInfo->realVarsOld, data->localData[0]->timeValue, data->localData[0]->realVars);
   }
 
   if(data->simulationInfo->sampleActivated == 1)
@@ -214,7 +214,7 @@ void handleEvents(DATA* data, threadData_t *threadData, LIST* eventLst, double *
         long ix = *((long*) listNodeData(it));
         int *eq_indexes;
         const char *exp_str = data->callback->zeroCrossingDescription(ix,&eq_indexes);
-        infoStreamPrintWithEquationIndexes(LOG_EVENTS, 0, eq_indexes, "[%ld] %s", ix+1, exp_str);
+        infoStreamPrintWithEquationIndexes(LOG_EVENTS, omc_dummyFileInfo, 0, eq_indexes, "[%ld] %s", ix+1, exp_str);
       }
     }
 
@@ -233,11 +233,11 @@ void handleEvents(DATA* data, threadData_t *threadData, LIST* eventLst, double *
         long ix = *((long*) listNodeData(listFirstNode(eventLst)));
         int *eq_indexes;
         const char *exp_str = data->callback->zeroCrossingDescription(ix,&eq_indexes);
-        infoStreamPrintWithEquationIndexes(LOG_STDOUT, 0, eq_indexes, "Chattering detected around time %.12g..%.12g (%d state events in a row with a total time delta less than the step size %.12g). This can be a performance bottleneck. Use -lv LOG_EVENTS for more information. The zero-crossing was: %s", t0, time, numEventLimit, data->simulationInfo->stepSize, exp_str);
+        infoStreamPrintWithEquationIndexes(LOG_STDOUT, omc_dummyFileInfo, 0, eq_indexes, "Chattering detected around time %.12g..%.12g (%d state events in a row with a total time delta less than the step size %.12g). This can be a performance bottleneck. Use -lv LOG_EVENTS for more information. The zero-crossing was: %s", t0, time, numEventLimit, data->simulationInfo->stepSize, exp_str);
         data->simulationInfo->chatteringInfo.messageEmitted = 1;
         if (omc_flag[FLAG_ABORT_SLOW])
         {
-          throwStreamPrintWithEquationIndexes(threadData, eq_indexes, "Aborting simulation due to chattering being detected and the simulation flags requesting we do not continue further.");
+          throwStreamPrintWithEquationIndexes(threadData, omc_dummyFileInfo, eq_indexes, "Aborting simulation due to chattering being detected and the simulation flags requesting we do not continue further.");
         }
       }
     }
@@ -284,43 +284,40 @@ void handleEvents(DATA* data, threadData_t *threadData, LIST* eventLst, double *
 /*! \fn findRoot
  *
  *  \param [ref] [data]
- *  \param [ref] [eventLst]
- *  \param [in]  [eventTime]
- *
- *  This function perform a root finding for Intervall = [oldTime, timeValue]
+ *  \param [ref] [threadData]
+ *  \param [ref] [eventList]
+ *  \param [in]  [time_left]
+ *  \param [in]  [values_left]
+ *  \param [in]  [time_right]
+ *  \param [in]  [values_right]
+ *  \return: first event of interval [time_left, time_right]
  */
-void findRoot(DATA* data, threadData_t *threadData, LIST *eventList, double *eventTime)
+double findRoot(DATA* data, threadData_t* threadData, LIST* eventList, double time_left, double* values_left, double time_right, double* values_right)
 {
   TRACE_PUSH
 
-  long event_id;
   LIST_NODE* it;
   fortran_integer i=0;
-  static LIST *tmpEventList = NULL;
+  LIST *tmpEventList = allocList(eventListAlloc, eventListFree, eventListCopy);
 
-  double *states_right = (double*) malloc(data->modelData->nStates * sizeof(double));
-  double *states_left = (double*) malloc(data->modelData->nStates * sizeof(double));
+  /* static work arrays */
+  double *states_left = data->simulationInfo->states_left;
+  double *states_right = data->simulationInfo->states_right;
 
-  double time_left = data->simulationInfo->timeValueOld;
-  double time_right = data->localData[0]->timeValue;
 
-  tmpEventList = allocList(sizeof(long));
-
-  assert(states_right);
-  assert(states_left);
+  /* write states to work arrays */
+  memcpy(states_left,  values_left,  data->modelData->nStates * sizeof(double));
+  memcpy(states_right, values_right, data->modelData->nStates * sizeof(double));
 
   for(it=listFirstNode(eventList); it; it=listNextNode(it))
   {
     infoStreamPrint(LOG_ZEROCROSSINGS, 0, "search for current event. Events in list: %ld", *((long*)listNodeData(it)));
   }
 
-  /* write states to work arrays */
-  memcpy(states_left,  data->simulationInfo->realVarsOld, data->modelData->nStates * sizeof(double));
-  memcpy(states_right, data->localData[0]->realVars    , data->modelData->nStates * sizeof(double));
-
   /* Search for event time and event_id with bisection method */
-  *eventTime = bisection(data, threadData, &time_left, &time_right, states_left, states_right, tmpEventList, eventList);
+  bisection(data, threadData, &time_left, &time_right, states_left, states_right, tmpEventList, eventList);
 
+  /* what happens here? */
   if(listLen(tmpEventList) == 0)
   {
     double value = fabs(data->simulationInfo->zeroCrossings[*((long*) listFirstData(eventList))]);
@@ -345,50 +342,31 @@ void findRoot(DATA* data, threadData_t *threadData, LIST *eventList, double *eve
 
   listClear(eventList);
 
-  if(ACTIVE_STREAM(LOG_EVENTS))
-  {
-    if(listLen(tmpEventList) > 0)
-    {
-      debugStreamPrint(LOG_EVENTS, 0, "found events: ");
-    }
-    else
-    {
-      debugStreamPrint(LOG_EVENTS, 0, "found event: ");
-    }
-  }
+  debugStreamPrint(LOG_EVENTS, 0, (listLen(tmpEventList) == 1) ? "found event: " : "found events: ");
   while(listLen(tmpEventList) > 0)
   {
-    event_id = *((long*)listFirstData(tmpEventList));
-    listPopFront(tmpEventList);
-
-    infoStreamPrint(LOG_ZEROCROSSINGS, 0, "Event id: %ld ", event_id);
-
-    listPushFront(eventList, &event_id);
+    long event_id = *((long*)listFirstData(tmpEventList));
+    listPushFrontNodeNoCopy(eventList, listPopFrontNode(tmpEventList));
+    infoStreamPrint(LOG_ZEROCROSSINGS, 0, "Event id: %ld", event_id);
   }
 
-  *eventTime = time_right;
-  debugStreamPrint(LOG_EVENTS, 0, "time: %.10e", *eventTime);
+  debugStreamPrint(LOG_EVENTS, 0, "time: %.10e", time_right);
 
   data->localData[0]->timeValue = time_left;
-  for(i=0; i < data->modelData->nStates; i++) {
-    data->localData[0]->realVars[i] = states_left[i];
-  }
+  memcpy(data->localData[0]->realVars, states_left, data->modelData->nStates * sizeof(double));
 
   /* determined continuous system */
   data->callback->updateContinuousSystem(data, threadData);
   updateRelationsPre(data);
   /*sim_result_emit(data);*/
 
-  data->localData[0]->timeValue = *eventTime;
-  for(i=0; i < data->modelData->nStates; i++)
-  {
-    data->localData[0]->realVars[i] = states_right[i];
-  }
+  data->localData[0]->timeValue = time_right;
+  memcpy(data->localData[0]->realVars, states_right, data->modelData->nStates * sizeof(double));
 
-  free(states_left);
-  free(states_right);
+  freeList(tmpEventList);
 
   TRACE_POP
+  return time_right;
 }
 
 /*! \fn bisection
@@ -400,11 +378,10 @@ void findRoot(DATA* data, threadData_t *threadData, LIST *eventList, double *eve
  *  \param [ref] [states_b]
  *  \param [ref] [eventListTmp]
  *  \param [in]  [eventList]
- *  \return Founded event time
  *
- *  Method to find root in Intervall [oldTime, timeValue]
+ *  Method to find root in interval [oldTime, timeValue]
  */
-double bisection(DATA* data, threadData_t *threadData, double* a, double* b, double* states_a, double* states_b, LIST *tmpEventList, LIST *eventList)
+void bisection(DATA* data, threadData_t *threadData, double* a, double* b, double* states_a, double* states_b, LIST *tmpEventList, LIST *eventList)
 {
   TRACE_PUSH
 
@@ -412,7 +389,7 @@ double bisection(DATA* data, threadData_t *threadData, double* a, double* b, dou
   double c;
   long i=0;
   /* n >= log(2)/log(2) + log(|b-a|/TOL)/log(2)*/
-  unsigned int n = 1 + ceil(log(fabs(*b - *a)/TTOL)/log(2));
+  unsigned int n = maxBisectionIterations > 0 ? maxBisectionIterations : 1 + ceil(log(fabs(*b - *a)/TTOL)/log(2));
 
   memcpy(data->simulationInfo->zeroCrossingsBackup, data->simulationInfo->zeroCrossings, data->modelData->nZeroCrossings * sizeof(modelica_real));
 
@@ -453,10 +430,8 @@ double bisection(DATA* data, threadData_t *threadData, double* a, double* b, dou
       memcpy(data->simulationInfo->zeroCrossings, data->simulationInfo->zeroCrossingsBackup, data->modelData->nZeroCrossings * sizeof(modelica_real));
     }
   }
-  c = 0.5*(*a + *b);
 
   TRACE_POP
-  return c;
 }
 
 /*! \fn checkZeroCrossings
@@ -522,6 +497,38 @@ void saveZeroCrossingsAfterEvent(DATA *data, threadData_t *threadData)
   TRACE_POP
 }
 
+/**
+ * @brief Allocate memory for eventList elements.
+ *
+ * @param data      Unused.
+ * @return void*    Allocated memory for LIST_NODE data.
+ */
+void* eventListAlloc(const void* data) {
+  void* newElem = malloc(sizeof(long));
+  assertStreamPrint(NULL, newElem != NULL, "eventListAlloc: Out of memory");
+  return newElem;
+}
+
+/**
+ * @brief Free memory allocated with eventListAlloc.
+ *
+ * @param data      Void pointer, representing index for new list element.
+ */
+void eventListFree(void* data) {
+  free(data);
+}
+
+/**
+ * @brief Copy data of eventList elements.
+ *
+ * @param dest    Void pointer of destination data, representing long index.
+ * @param src     Void pointer of source data, representing long index.
+ */
+void eventListCopy(void* dest, const void* src) {
+  long* dest_event = (long*) dest;
+  *dest_event = *((long*) src);
+}
+
 #ifdef __cplusplus
 }
 #endif
