@@ -284,7 +284,7 @@ void AddComponentCommand::redoInternal()
       OMCProxy *pOMCProxy = MainWindow::instance()->getOMCProxy();
       const QString arrayIndex = QString("{%1}").arg(mpDiagramComponent->getElementInfo()->getArrayIndex());
       if (!pOMCProxy->setComponentDimensions(modelName, mpDiagramComponent->getElementInfo()->getName(), arrayIndex)) {
-        QMessageBox::critical(MainWindow::instance(), QString("%1 - %2").arg(Helper::applicationName, Helper::error), pOMCProxy->getResult(), Helper::ok);
+        QMessageBox::critical(MainWindow::instance(), QString("%1 - %2").arg(Helper::applicationName, Helper::error), pOMCProxy->getResult(), QMessageBox::Ok);
         pOMCProxy->printMessagesStringInternal();
       }
     }
@@ -487,7 +487,7 @@ void UpdateElementAttributesCommand::updateComponentAttributes(Element *pCompone
       }
     }
   } else {
-    QMessageBox::critical(MainWindow::instance(), QString("%1 - %2").arg(Helper::applicationName, Helper::error), pOMCProxy->getResult(), Helper::ok);
+    QMessageBox::critical(MainWindow::instance(), QString("%1 - %2").arg(Helper::applicationName, Helper::error), pOMCProxy->getResult(), QMessageBox::Ok);
     pOMCProxy->printMessagesStringInternal();
   }
   // update the component comment only if its changed.
@@ -510,7 +510,7 @@ void UpdateElementAttributesCommand::updateComponentAttributes(Element *pCompone
         }
       }
     } else {
-      QMessageBox::critical(MainWindow::instance(), QString("%1 - %2").arg(Helper::applicationName, Helper::error), pOMCProxy->getResult(), Helper::ok);
+      QMessageBox::critical(MainWindow::instance(), QString("%1 - %2").arg(Helper::applicationName, Helper::error), pOMCProxy->getResult(), QMessageBox::Ok);
       pOMCProxy->printMessagesStringInternal();
     }
   }
@@ -535,7 +535,7 @@ void UpdateElementAttributesCommand::updateComponentAttributes(Element *pCompone
         }
       }
     } else {
-      QMessageBox::critical(MainWindow::instance(), QString("%1 - %2").arg(Helper::applicationName, Helper::error), pOMCProxy->getResult(), Helper::ok);
+      QMessageBox::critical(MainWindow::instance(), QString("%1 - %2").arg(Helper::applicationName, Helper::error), pOMCProxy->getResult(), QMessageBox::Ok);
       pOMCProxy->printMessagesStringInternal();
     }
   }
@@ -545,7 +545,7 @@ void UpdateElementAttributesCommand::updateComponentAttributes(Element *pCompone
     if (pOMCProxy->setComponentDimensions(modelName, pComponent->getElementInfo()->getName(), arrayIndex)) {
       pComponent->getElementInfo()->setArrayIndex(arrayIndex);
     } else {
-      QMessageBox::critical(MainWindow::instance(), QString("%1 - %2").arg(Helper::applicationName, Helper::error), pOMCProxy->getResult(), Helper::ok);
+      QMessageBox::critical(MainWindow::instance(), QString("%1 - %2").arg(Helper::applicationName, Helper::error), pOMCProxy->getResult(), QMessageBox::Ok);
       pOMCProxy->printMessagesStringInternal();
     }
   }
@@ -1592,9 +1592,11 @@ void OMSimulatorUndoCommand::switchToEditedModelWidget()
  * \param oldModelInfo
  * \param newModelInfo
  * \param commandText
+ * \param commandType
  * \param pParent
  */
-OMCUndoCommand::OMCUndoCommand(LibraryTreeItem *pLibraryTreeItem, const ModelInfo &oldModelInfo, const ModelInfo &newModelInfo, const QString &commandText, UndoCommand *pParent)
+OMCUndoCommand::OMCUndoCommand(LibraryTreeItem *pLibraryTreeItem, const ModelInfo &oldModelInfo, const ModelInfo &newModelInfo, const QString &commandText,
+                               bool skipGetModelInstance, UndoCommand *pParent)
   : UndoCommand(pParent)
 {
   mpLibraryTreeItem = pLibraryTreeItem;
@@ -1606,6 +1608,7 @@ OMCUndoCommand::OMCUndoCommand(LibraryTreeItem *pLibraryTreeItem, const ModelInf
   mNewModelText = MainWindow::instance()->getOMCProxy()->listFile(mpParentContainingLibraryTreeItem->getNameStructure());
   mNewModelInfo = newModelInfo;
   setText(commandText);
+  mSkipGetModelInstance = skipGetModelInstance;
 }
 
 /*!
@@ -1615,7 +1618,9 @@ OMCUndoCommand::OMCUndoCommand(LibraryTreeItem *pLibraryTreeItem, const ModelInf
 void OMCUndoCommand::redoInternal()
 {
   MainWindow::instance()->getOMCProxy()->loadString(mNewModelText, mpParentContainingLibraryTreeItem->getFileName());
-  mpLibraryTreeItem->getModelWidget()->reDrawModelWidget(mNewModelInfo);
+  if (!mSkipGetModelInstance || mUndoCalledOnce) {
+    mpLibraryTreeItem->getModelWidget()->reDrawModelWidget(mNewModelInfo);
+  }
 }
 
 /*!
@@ -1624,6 +1629,7 @@ void OMCUndoCommand::redoInternal()
  */
 void OMCUndoCommand::undo()
 {
+  mUndoCalledOnce = true;
   MainWindow::instance()->getOMCProxy()->loadString(mOldModelText, mpParentContainingLibraryTreeItem->getFileName());
   mpLibraryTreeItem->getModelWidget()->reDrawModelWidget(mOldModelInfo);
 }
