@@ -397,7 +397,7 @@ namespace IAEX {
     {
       inCommand = false;
       QTextCursor tc(textCursor());
-      int i = toPlainText().indexOf(QRegExp("\\n|$"), tc.position());
+      int i = toPlainText().indexOf(QRegularExpression("\\n|$"), tc.position());
 
       if(i -tc.position() > 0)
         tc.setPosition(i, QTextCursor::KeepAnchor);
@@ -422,7 +422,7 @@ namespace IAEX {
         int k2 = t.blockNumber();
         QTextBlock b = t.block();
         int k = b.userState();
-        int prevLevel = b.text().indexOf(QRegExp("\\S"));
+        int prevLevel = b.text().indexOf(QRegularExpression("\\S"));
 
         while(k2 >= 0 && !indentationStates.contains(k))
         {
@@ -493,7 +493,7 @@ namespace IAEX {
 
   bool MyTextEdit2a::lessIndented(QString s)
   {
-    QRegExp l("\\b(equation|algorithm|public|protected|else|elseif)\\b");
+    QRegularExpression l("\\b(equation|algorithm|public|protected|else|elseif)\\b");
     return s.indexOf(l) >= 0;
   }
 
@@ -529,7 +529,7 @@ namespace IAEX {
 
   void MyTextEdit2a::goToPos(const QUrl& u)
   {
-    QRegExp e("/|\\-|:");
+    QRegularExpression e("/|\\-|:");
     int r=u.path().section(e, 1,1).toInt();
     int c=u.path().section(e, 2,2).toInt();
     int r2=u.path().section(e, 3,3).toInt();
@@ -704,7 +704,7 @@ namespace IAEX {
     setMainWidget(main);
 
     layout_ = new QGridLayout(mainWidget());
-    layout_->setMargin(0);
+    layout_->setContentsMargins(0, 0, 0, 0);
     layout_->setSpacing(0);
 
     setTreeWidget(new InputTreeView(this));
@@ -1027,7 +1027,7 @@ namespace IAEX {
     tmp.replace( "&nbsp;&nbsp;&nbsp;&nbsp;", "  " );
 
     // 2005-12-08 AF, remove any <span style tag
-    QRegExp spanEnd( "</span>" );
+    QRegularExpression spanEnd( "</span>" );
     tmp.remove( spanEnd );
     int pos = 0;
     while( true )
@@ -1611,7 +1611,7 @@ namespace IAEX {
       setState(Finished);
 
     output_->selectAll();
-    res = res.replace(QRegExp("\\[<interactive>:([\\d]+):([\\d]+)-([\\d]+):([\\d]+):.*\\](.*)"),"[\\1:\\2-\\3:\\4]\\5");
+    res = res.replace(QRegularExpression("\\[<interactive>:([\\d]+):([\\d]+)-([\\d]+):([\\d]+):.*\\](.*)"),"[\\1:\\2-\\3:\\4]\\5");
     output_->textCursor().insertText( res );
 
     QPalette pal = output_->palette(); // define palette for textEdit.
@@ -1623,7 +1623,9 @@ namespace IAEX {
       pal.setColor(QPalette::Base, Qt::white);
     }
     output_->setPalette(pal);
-
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+ // TODO
+#else
     QRegExp e("([\\d]+:[\\d]+-[\\d]+:[\\d]+)|([\\d]+:[\\d]+)");
     int cap = 1;
     int p=0;
@@ -1650,7 +1652,7 @@ namespace IAEX {
       actions.push_back(a);
     }
     emit setStatusMenu(actions);
-
+#endif
     ++numEvals_;
     contentChanged();
 
